Module templates

Module templates 

Structs

TemplateAssets

Functions

load_templates
Load embedded templates into a Tera instance.
load_templates_with_custom_dir
Load embedded templates, then overlay templates from a custom directory. Custom templates with the same name override embedded ones.