pub fn plan_security(
repo: &str,
current: &SecurityState,
desired: &SecurityConfig,
) -> RepoPlanExpand description
Diff the current security state against the desired config.
pub fn plan_security(
repo: &str,
current: &SecurityState,
desired: &SecurityConfig,
) -> RepoPlanDiff the current security state against the desired config.