pub async fn verify_security(
client: &Client,
plans: &[RepoPlan],
desired: &SecurityConfig,
) -> Result<VerificationReport>Expand description
Re-read security state and verify it matches the plan.
pub async fn verify_security(
client: &Client,
plans: &[RepoPlan],
desired: &SecurityConfig,
) -> Result<VerificationReport>Re-read security state and verify it matches the plan.